import{h as o}from"./QBtn.dd872fc6.js";import{a8 as r,u as s,ah as a,aa as t,y as l}from"./index.2c15b870.js";import"./dom.44408ff4.js";const n={class:"fullscreen bg-blue text-white text-center q-pa-md flex flex-center"},u=r({name:"ErrorNotFound",__name:"ErrorNotFound",setup(i){return(c,e)=>(s(),a("div",n,[t("div",null,[e[0]||(e[0]=t("div",{style:{"font-size":"30vh"}}," 404 ",-1)),e[1]||(e[1]=t("div",{class:"text-h2",style:{opacity:".4"}}," Oops. Nothing here... ",-1)),l(o,{class:"q-mt-xl",color:"white","text-color":"blue",unelevated:"",to:"/",label:"Go Home","no-caps":""})])]))}});export{u as default};
