import{b as e,a as o}from"./index.2c15b870.js";const i=o.create({baseURL:"https://api.example.com"});var t=e(({app:a})=>{a.config.globalProperties.$axios=o,a.config.globalProperties.$api=i});export{i as api,t as default};
