.runs-table-container[data-v-2bce7580]{max-height:500px;display:flex;flex-direction:column}.runs-table[data-v-2bce7580]{flex:1;overflow-y:auto}.panel[data-v-2bce7580]{display:flex;flex-wrap:wrap}.panel-item[data-v-2bce7580]{display:flex;flex-direction:column}.fairness-chart-container[data-v-2bce7580]{display:inline-block;height:31.25rem;width:100%}.chart-container[data-v-2bce7580]{display:inline-block;height:21.875rem;width:18.75rem}.panel-settings[data-v-2bce7580]{display:flex;justify-content:end}.fairness-table[data-v-2bce7580]{max-width:100%;overflow:auto}[data-v-2bce7580] .fairness-table thead tr:first-child th:first-child,[data-v-2bce7580] .fairness-table td:first-child{background-color:#fff}[data-v-2bce7580] .fairness-table th:first-child,[data-v-2bce7580] .fairness-table td:first-child{position:sticky!important;left:0!important;z-index:1!important}.fairness-header{width:8.5rem!important;min-width:8.5rem!important;max-width:8.5rem!important;white-space:normal!important;word-break:break-word!important;overflow-wrap:anywhere!important;vertical-align:top}.distribution-grid[data-v-fc3b65b6]{display:grid;grid-template-columns:repeat(auto-fit,minmax(300px,1fr));gap:16px;padding:16px}.chart-container[data-v-fc3b65b6]{border:1px solid #ccc;padding:8px;background:#fff}.chart[data-v-fc3b65b6]{width:100%;height:300px}.chart-group[data-v-21bd111e]{display:flex}.chart-container[data-v-21bd111e]{position:relative;height:28.125rem;width:28.125rem}.highlight-row[data-v-21bd111e]{background-color:#f5f5f5}.main-header[data-v-21bd111e]{display:flex;justify-content:space-between}.open-full[data-v-21bd111e]{display:none}@media (max-width: 1150px){.open-full[data-v-21bd111e]{display:inline-flex}}
